#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from pyams_i18n.interfaces import II18n
from pyams_portal.interfaces import IPortalContext, IPortletRenderer
from pyams_portal.portlet import PortletRenderer
from pyams_portal.portlets.html.interfaces import IHTMLPortletSettings, IRawPortletSettings
from pyams_skin.layer import IPyAMSLayer
from pyams_template.template import template_config
from pyams_utils.adapter import adapter_config
from pyams_utils.fanstatic import ExternalResource
from pyams_utils.pygments import render_source, IPygmentsCodeConfiguration, library

from pyams_portal import _


#
# Raw code renderer
#

@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, IRawPortletSettings), provides=IPortletRenderer)
@template_config(template='templates/raw.pt', layer=IPyAMSLayer)
class RawPortletDefaultRenderer(PortletRenderer):
    """Raw HTML portlet renderer"""

    label = _("Default code renderer")
    weight = 1


#
# Formatted source code renderer
#

@adapter_config(name='source-code',
                context=(IPortalContext, IPyAMSLayer, Interface, IRawPortletSettings),
                provides=IPortletRenderer)
@template_config(template='templates/code.pt', layer=IPyAMSLayer)
class RawPortletSourceCodeRenderer(PortletRenderer):
    """Formatted source code portlet renderer"""

    label = _("Formatted source code renderer")
    weight = 10

    settings_interface = IPygmentsCodeConfiguration

    @property
    def resources(self):
        settings = self.settings
        yield ExternalResource(library, 'get-pygments-style.css?style={}'.format(settings.style),
                               resource_type='css')

    @property
    def body(self):
        code = II18n(self.settings).query_attribute('body', request=self.request)
        if code:
            return render_source(code, self.renderer_settings)
        return ''


#
# Formatted HTML renderer
#

@adapter_config(context=(IPortalContext, IPyAMSLayer, Interface, IHTMLPortletSettings), provides=IPortletRenderer)
@template_config(template='templates/html.pt', layer=IPyAMSLayer)
class HTMLPortletDefaultRenderer(PortletRenderer):
    """Rich text portlet renderer"""

    label = _("Default text renderer")
